#
# spec file for package python-aodhclient
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname aodhclient
Name:           python-aodhclient
Version:        0.9.0
Release:        lp150.2.1
Summary:        Python client library for Aodh
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/openstack/python-aodhclient
Source0:        https://files.pythonhosted.org/packages/source/a/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-cliff >= 2.8.0
BuildRequires:  python-devel
BuildRequires:  python-keystoneauth1 >= 3.3.0
BuildRequires:  python-oslo.serialization >= 2.18.0
BuildRequires:  python-oslo.utils >= 3.33.0
BuildRequires:  python-oslotest >= 3.2.0
BuildRequires:  python-pbr >= 2.0.0
BuildRequires:  python-pyparsing >= 2.1.0
BuildRequires:  python-python-subunit >= 1.0.0
BuildRequires:  python-requests >= 2.14.2
BuildRequires:  python-setuptools >= 16.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testtools >= 2.2.0
Requires:       python-cliff >= 2.8.0
Requires:       python-debtcollector >= 1.2.0
Requires:       python-keystoneauth1 >= 3.3.0
Requires:       python-osc-lib >= 1.8.0
Requires:       python-oslo.i18n >= 3.15.3
Requires:       python-oslo.serialization >= 2.18.0
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-pbr >= 2.0.0
Requires:       python-pyparsing >= 2.1.0
Requires:       python-six >= 1.10.0
BuildArch:      noarch

%description
This is a client library for Aodh built on the Aodh API. It
provides a Python API (the aodhclient module) and a command-line tool.

%package doc
Summary:        Documentation for OpenStack Aodh API Client
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 4.7.0

%description      doc
This is a client library for Aodh built on the Aodh API. It
provides a Python API (the aodhclient module) and a command-line tool.

This package contains auto-generated documentation.

%prep
%autosetup -n %{sname}-%{version}
%py_req_cleanup

%build
%py2_build

%install
%py2_install

%{__python2} setup.py build_sphinx
# Fix hidden-file-or-dir warnings
rm -rf html/.doctrees html/.buildinfo

%check
# FIXME: only run unittests for now.
export OS_TEST_PATH=./aodhclient/tests/unit
PYTHONPATH=. %{__python2} setup.py testr

%files
%doc README.rst
%license LICENSE
%{_bindir}/aodh
%{python2_sitelib}/aodhclient
%{python2_sitelib}/*.egg-info

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Tue Aug  1 2017 cloud-devel@suse.de
- update to version 0.9.0
  - Remove unused test dependency
  - Remove upper cap on pbr
  - Clean deprecated "query" paremeter in alarm.list()
  - Trivial-fix: make the capabilities help message more specific in OSC
  - Correct the port number of gnocchi endpoint
  - Trivial: remove support for py34
  - Update reno for stable/ocata
  - Remove the duplicated __version__ definition
* Wed Jun  7 2017 dmueller@suse.com
- fix requirements
* Tue Feb 21 2017 cloud-devel@suse.de
- update to version 0.8.0:
  - Add plug-in summary for osc doc
  - Update reno for stable/newton
  - Modified the help info.
  - [doc] Note lack of constraints is a choice
  - Bump hacking to 0.12
  - Add missing pyparsing to requirements.txt
  - Enable coverage report in console output
  - Enable release notes translation
  - Replaces uuid.uuid4 with uuidutils.generate_uuid()
  - Clean imports in code
  - Remove 'MANIFEST.in'
  - Extras usage for test requirements + basic auth against Gnocch
* Wed Sep 28 2016 tbechtold@suse.com
  update to version 0.7.0
  * Use osc-lib instead of openstackclient
  * Add --query to alarm list
  * add valid choice for alarm type help text
  * add alarm history unit test
  * fix help text for option --composite-rule
  * fix KeyError when credential is invalid
  * Fix incorrect string format mapping
  * Add explanation for how to get meter name
  * Add --filter to "alarm list"
  * [Trivial] Remove executable privilege of doc/source/conf.py
  * Remove Babel dependency
  * Use overtest to run Gnocchi in tests
  * Correct and add examples in docs of CLI
  * Use assert_called_once_with() in test_alarm_cli.py
  * Switch from deprecated tempest-lib to tempest
  * Remove discover from test-requirements
  * Split alarm query and alarm list in SDK layer.
  * Add pagination support in Aodhclient
  * Add name support for show, update and delete
  * remove tempest test for alarm name unique constraint
  * Prepare compatibility with OSC
  * Fix a minor doc error
  * Add releasenotes for Newton updates
  * add default value for http_status in ClientException
  * Remove keystonemiddleware dependency
  * add mock to test requirement list
  * Fix the wrong error info of parameter resource-type
  * Add Python 3.5 classifier and venv
  * Remove unused package requirement of "futurist"
  * Support easier query usage for alarm history search
  * Only install hacking in pep8
  * Trival: Remove unused logging import
  * Don't support "alarm search" and mandatory --type in "alarm list"
  * improve threshold & event alarm query formatting
  * shell: fix meter help string
  * Add unit test to validate composite alarm args
  * Enable releasenotes documentation
  * Allow to start Aodh command with OSC
  * Fix aodh client fails when command with the arg --time-constraint
  * exceptions: make error code be implicit
  * refactor code of adding alarm id and name arguments
  * Add event_id for alarm-history display
  * Bump hacking to 0.11
  * format the output of time_constraints
  * tox: remove useless install_command
  * shell: treat alarm id as name if it is not uuid like
  * Remove unused mailmap file
  * Fix the -q/--query in threshold alarm creation
  * Update the home-page with developer documentation
  * Trival fix a typo
  * Support get/set alarm state interfaces
  * Clean flake8 paths and unused config options
  * remove unnecessary slashes
  * Use pifpaf to setup tests
- update _service and switch to upstream spec
* Mon Mar 14 2016 cloud-devel@suse.de
- Update to version aodhclient-0.3.1.dev13:
  * Trival fix a typo
  * Fix aodh client fails when command with the arg --time-constraint
  * Fix the -q/--query in threshold alarm creation
* Wed Mar  9 2016 cloud-devel@suse.de
- Update to version aodhclient-0.3.1.dev8:
  * Use assert_called_once_with() in test_alarm_cli.py
  * Fix the wrong error info of parameter resource-type
* Tue Mar  8 2016 cloud-devel@suse.de
- Update to version aodhclient-0.3.1.dev4:
  * Fix a minor doc error
  * Remove unused package requirement of "futurist"
* Thu Mar  3 2016 cloud-devel@suse.de
- Update to version aodhclient-0.3.1.dev1:
  0.3.0
  * Use cli.base.execute of tempest-lib
  * Add composite rule alarm support in aodhclient
  * Make the alarm list output more concise
  0.2.0
  * add alarm history unit test
* Fri Feb 26 2016 cloud-devel@suse.de
- Update to version aodhclient-0.1.1.dev12:
  * Skip the version 1.16.0 of cliff
  * Remove unused method
  * Add abbreviation of --meter-name hint in threshold alarm creation
  * Return the error message of API request failure
  * Add some unit test cases
  * Add gnocchi alarm rules
  * cleanup existing tests
  * check the alarm type when list alarm
  0.1.0
* Mon Jan 25 2016 aplanas@suse.com
- Initial package
